AuthMethod

Enum AuthMethod 

#[repr(u8)]
pub enum AuthMethod { NoAuthRequired, Gssapi, UsernamePassword, IanaAssigned(u8), PrivateMethods(u8), NoAcceptableMethods, }
The AuthMethod enum represents the various authentication methods supported by the SOCKS5 protocol.

Variants



NoAuthRequired

No authentication is required. This method allows clients to connect without providing any credentials.



Gssapi

GSSAPI (Generic Security Services Application Program Interface) authentication method.



UsernamePassword

Username and password authentication method. This method requires clients to provide a username and password.



IanaAssigned(u8)

IANA (Internet Assigned Numbers Authority) assigned authentication methods, represented by a u8 value.



PrivateMethods(u8)

Private authentication methods, represented by a u8 value. These are methods that are not standardized and can be defined by private agreements.



NoAcceptableMethods

Indicates that no acceptable authentication methods are available. This method is used to indicate that the server does not accept any of the methods proposed by the client.